@@ -24,10 +24,13 @@ Bio::Phylo::PhyloWS::Client - Base class for phylogenetic web service clients
  use Bio::Phylo::Factory;
  
  my $fac = Bio::Phylo::Factory->new;
- my $client = $fac->create_client( '-url' => 'http://nexml-dev.nescent.org/nexml/phylows/tolweb/phylows/' );
+ my $client = $fac->create_client( 
+ 	'-base_uri'  => 'http://nexml-dev.nescent.org/nexml/phylows/tolweb/phylows/',
+ 	'-authority' => 'uBioNB',
+ );
  my $desc = $client->get_query_result( 
-	'-query'        => 'Homo sapiens', 
-	'-section'      => 'taxon',
+	'-query'     => 'Homo sapiens', 
+	'-section'   => 'taxon',
  );
  for my $res ( @{ $desc->get_entities } ) {
 	my $proj = $client->get_record( '-guid' => $res->get_guid );
@@ -68,10 +71,12 @@ the PhyloWS (L<http://evoinfo.nescent.org/PhyloWS>) recommendations.
         my $self = $class->SUPER::new(@_);
 
         # store a user agent object to delegate http stuff to
-        my $ua = LWP::UserAgent->new;
-        $ua->timeout(300);
-        $ua->env_proxy;
-        $ua{ $self->get_id } = $ua;
+        if ( not $self->get_ua ) {
+            my $ua = LWP::UserAgent->new;
+            $ua->timeout(300);
+            $ua->env_proxy;
+            $self->set_ua($ua);
+        }
         return $self;
     }
     my $ua = sub {
@@ -80,6 +85,40 @@ the PhyloWS (L<http://evoinfo.nescent.org/PhyloWS>) recommendations.
 
 =back
 
+=head2 MUTATORS
+
+=over
+
+=item set_ua()
+
+Assigns a new L<LWP::UserAgent> object that the client uses to communicate 
+with the service. Typically you don't have to use this unless you have to
+configure a user agent for things such as proxies. Normally a default user
+agent is instantiated when the client constructor is called.
+
+ Type    : Mutator
+ Title   : set_ua
+ Usage   : $obj->set_ua( LWP::UserAgent->new );
+ Function: Assigns another (non-default) user agent
+ Returns : $self
+ Args    : An LWP::UserAgent object (or child class)
+
+=cut
+
+    sub set_ua {
+    	my $self = shift;
+    	my $arg = shift;
+    	if ( UNIVERSAL::isa( $arg, 'LWP::UserAgent' ) ) {
+    	    $ua{ $self->get_id } = $arg;	
+    	}
+    	else {
+    	    throw 'BadArgs' => "'$arg' is not an LWP::UserAgent";	
+    	}
+    	return $self;
+    }
+
+=back
+
 =head2 ACCESSORS
 
 =over
@@ -212,6 +251,21 @@ Gets a PhyloWS database record
         }
     }
 
+=item get_ua()
+
+Gets the underlying L<LWP::UserAgent> object that the client uses to communicate with the service
+
+ Type    : Accessor
+ Title   : get_ua
+ Usage   : my $ua = $obj->get_ua;
+ Function: Gets user agent
+ Returns : LWP::UserAgent object
+ Args    : None
+
+=cut
+
+    sub get_ua { $ua{ shift->get_id } }
+
     sub _cleanup {
         my $self = shift;
         my $id   = $self->get_id;
@@ -228,6 +282,9 @@ Gets a PhyloWS database record
 
 =head1 SEE ALSO
 
+There is a mailing list at L<https://groups.google.com/forum/#!forum/bio-phylo> 
+for any user or developer questions and discussions.
+
 Also see the manual: L<Bio::Phylo::Manual> and L<http://rutgervos.blogspot.com>
 
 =head1 CITATION
